/*! ********************************************
 * Effector.hpp
 * Copyright 2019 masahiro takamoto (MotChan)
 * Distributed under the MIT license. 
 * see -> sora/license.txt
 ******************************************** */
#ifndef INCLUDE_Effector_h
#define INCLUDE_Effector_h

#ifndef INCLUDE_GrayBox_Types_h
#include "Types.h"
#endif

namespace sora {
namespace graybox {
namespace efx {
/***********************************************
	Class	EffectorBase
************************************************/
class EffectorBase
{
protected:
	float _mix     = 0.0f;  // 0.0 ~ 1.0
	float _antiMix = 1.0f;  // 0.0 ~ 1.0
public:
	virtual float getMix(){ return _mix; }
	virtual void setMix(float val){ _mix = val; _antiMix = 1.0f - _mix; }
	virtual void applyEffect(float* const& outL, float* const& outR, const int32& startFrame, const int32& sampleFrames) = 0;
	virtual void resetParameters(){}
	virtual void clearBuffer(){}
	virtual void initialize(){}
// Constructor
protected:
	EffectorBase(){}
// Copy Constructor
	EffectorBase(const EffectorBase&) = delete;
	EffectorBase& operator = (const EffectorBase&) = delete;
// Move Constructor
	EffectorBase(EffectorBase&&) noexcept;
	EffectorBase& operator = (EffectorBase&&) = delete;
// Destructor
	virtual ~EffectorBase(){}
};
}}}
#endif