/*! ********************************************
 * Tone.cpp
 * Copyright 2019 masahiro takamoto (MotChan)
 * Distributed under the MIT license. 
 * see -> sora/license.txt
 ******************************************** */
#ifndef INCLUDE_Tone_h
#include "Tone.hpp"
#endif

namespace sora {
namespace graybox {
namespace synth {
/***********************************************
	Class	SamplerPreset
************************************************/
void SamplerPreset::copy(const SamplerPreset& preset)
{
	for (int i = 0; i < 16; ++i)toneName[i] = preset.toneName[i];
	smplNum = preset.smplNum;
	pan = preset.pan;
	octv = preset.octv;
	tune = preset.tune;
	tl = preset.tl;
	ar = preset.ar;
	dr = preset.dr;
	sl = preset.sl;
	rr = preset.rr;
}
void SamplerPreset::reset()
{
	for (int i = 0; i < 16; ++i)toneName[i] = ' ';
	smplNum = 0;
	pan = 64;
	octv = 8;
	tune = 8192;
	tl = 0;
	ar = 127;
	dr = 0;
	sl = 127;
	rr = 120;
}
/***********************************************
	Class	TonePresetWT
************************************************/
void TonePresetWT::copy(const TonePresetWT& preset)
{
	for (int i = 0; i < 16; ++i)toneName[i] = preset.toneName[i];
	strc = preset.strc;
	wave = preset.wave;
	tune = preset.tune;
		
	kf = preset.kf;
	kfStart = preset.kfStart;
		
	tl = preset.tl;
	ar = preset.ar;
	dr = preset.dr;
	sl = preset.sl;
	rr = preset.rr;
		
	lms = preset.lms;
	lfoFreq = preset.lfoFreq;
		
	key = preset.key;
	pan = preset.pan;
}
void TonePresetWT::reset()
{
	for (int i = 0; i < 16; ++i)toneName[i] = ' ';
	key = 64;
	pan = 64;
	lfoFreq = 2048;
	strc = 0;
	tune = 8192;
	lms = 0;
	wave = 0;
	tl = 0;
	ar = 127;
	dr = 100;
	sl = 0;
	rr = 120;
	kf = 0;
	kfStart	= 48;
}
/***********************************************
	Class	TonePresetPCM
************************************************/
void TonePresetPCM::copy(const TonePresetPCM& preset)
{
	for (int i = 0; i < 16; ++i)toneName[i] = preset.toneName[i];
	strc = preset.strc;
	smplNum = preset.smplNum;
	tune = preset.tune;
		
	kf = preset.kf;
	kfStart = preset.kfStart;
		
	tl = preset.tl;
	ar = preset.ar;
	dr = preset.dr;
	sl = preset.sl;
	rr = preset.rr;
		
	lms = preset.lms;
	lfoFreq = preset.lfoFreq;
}
void TonePresetPCM::reset()
{
	for (int i = 0; i < 16; ++i)toneName[i] = ' ';
	lfoFreq = 2048;
	strc = 0;
	tune = 8192;
	lms = 0;
	smplNum = 0;
	tl = 0;
	ar = 126;
	dr = 100;
	sl = 0;
	rr = 120;
	kf = 0;
	kfStart	= 48;
}
/***********************************************
	Class	TonePresetFM
************************************************/
void TonePresetFM::copy(const TonePresetFM& preset)
{
	for (int i = 0; i < 16; ++i)toneName[i] = preset.toneName[i];
	key = preset.key;
	pan = preset.pan;
	lfoWave = preset.lfoWave;
	lfoFreq = preset.lfoFreq;		
	fl = preset.fl;
	strc = preset.strc;
	// operator 0
	tlVelCtrl_0	= preset.tlVelCtrl_0;
	mul_0		= preset.mul_0;
	tune_0		= preset.tune_0;
	lms_0		= preset.lms_0;
	wave_0		= preset.wave_0;
	tl_0		= preset.tl_0;
	ar_0		= preset.ar_0;
	dr_0		= preset.dr_0;
	sl_0		= preset.sl_0;
	rr_0		= preset.rr_0;
	kf_0		= preset.kf_0;
	kfStart_0	= preset.kfStart_0;
	// operator 1
	tlVelCtrl_1	= preset.tlVelCtrl_1;
	mul_1		= preset.mul_1;
	tune_1		= preset.tune_1;
	lms_1		= preset.lms_1;
	wave_1		= preset.wave_1;
	tl_1		= preset.tl_1;
	ar_1		= preset.ar_1;
	dr_1		= preset.dr_1;
	sl_1		= preset.sl_1;
	rr_1		= preset.rr_1;
	kf_1		= preset.kf_1;
	kfStart_1	= preset.kfStart_1;
}
void TonePresetFM::reset()
{
	for (int i = 0; i < 16; ++i)toneName[i] = ' ';
	key = 64;
	pan = 64;
	lfoWave = 0;
	lfoFreq = 2048;
	fl = 127;
	strc = 0;
	// operator 0
	tlVelCtrl_0	= 0;
	mul_0		= 1;
	tune_0		= 8192;
	lms_0 		= 0;
	wave_0		= 0;
	tl_0		= 0;
	ar_0		= 124;
	dr_0		= 100;
	sl_0		= 0;
	rr_0		= 120;
	kf_0		= 0;
	kfStart_0	= 48;
	// operator 1
	tlVelCtrl_1	= 0;
	mul_1		= 1;
	tune_1		= 8192;
	lms_1 		= 0;
	wave_1		= 0;
	tl_1		= 0;
	ar_1		= 124;
	dr_1		= 100;
	sl_1		= 0;
	rr_1		= 120;
	kf_1		= 0;
	kfStart_1	= 48;
}
}}}